==> php81-nextcloud-26.0.5.tgz: share/nextcloud/apps/activity/l10n/en_GB.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "Copied!",
    "Not supported!" : "Not supported!",
    "Press ⌘-C to copy." : "Press ⌘-C to copy.",
    "Press Ctrl-C to copy." : "Press Ctrl-C to copy.",
    "{name} (invisible)" : "{name} (invisible)",
    "{name} (restricted)" : "{name} (restricted)",
    "Home" : "Home",
    "in {path}" : "in {path}",
    "This stream will show events like additions, changes & shares" : "This stream will show events like additions, changes & shares",
    "There are no events for this filter" : "There are no events for this filter",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "Open {filename}" : "Open {filename}",
    "Activity" : "Activity",
    "Personal activity feed for %s" : "Personal activity feed for %s",
    "Your feed URL is invalid" : "Your feed URL is invalid",
    "Your settings have been updated." : "Your settings have been updated.",
    "Settings have been updated." : "Settings have been updated.",
    "Recent activity" : "Recent activity",
    "More activities" : "More activities",
    "Daily activity summary for %s" : "Daily activity summary for %s",
    "_and %n more _::_and %n more _" : ["and %n more","and %n more"],
    "All activities" : "All activities",
    "By others" : "By others",
    "By you" : "By you",
    "Activity at %s" : "Activity at %s",
    "Hello %s" : "Hello %s",
    "Hello %s," : "Hello %s,",
    "There was some activity at %s" : "There was some activity at %s",
    "Mail" : "Mail",
    "Push" : "Push",
    "Notifications" : "Notifications",
    "This application enables people to view a log of activities about them, their files or other data." : "This application enables people to view a log of activities about them, their files or other data.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation.",
    "Activity notification configuration" : "Activity notification configuration",
    "Send email" : "Send email",
    "Send push notification" : "Send push notification",
    "You need to set up your email address before you can receive notification emails." : "You need to set up your email address before you can receive notification emails.",
    "Send activity emails" : "Send activity emails",
    "As soon as possible" : "As soon as possible",
    "Hourly" : "Hourly",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "No activity yet" : "No activity yet",
    "Notification" : "Notification",
    "Enable notification emails" : "Enable notification emails",
    "Choose for which activities you want to get an email or push notification." : "Choose for which activities you want to get an email or push notification.",
    "Choose for which activities you want to get a push notification." : "Choose for which activities you want to get a push notification.",
    "Daily activity summary" : "Daily activity summary",
    "Send daily activity summary in the morning" : "Send daily activity summary in the morning",
    "Activities" : "Activities",
    "No activities" : "No activities",
    "Default settings" : "Default settings",
    "Configure the default notification settings for new accounts." : "Configure the default notification settings for new accounts.",
    "Unable to save the settings" : "Unable to save the settings",
    "Activity feed" : "Activity feed",
    "Activity settings" : "Activity settings",
    "Enable RSS feed" : "Enable RSS feed",
    "RSS feed" : "RSS feed",
    "Copy RSS feed link" : "Copy RSS feed link",
    "Personal notification settings" : "Personal notification settings",
    "No more events to load" : "No more events to load",
    "This application enables users to view a log of activities about them or about files." : "This application enables users to view a log of activities about them or about files.",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation.",
    "Unable to load the activity list" : "Unable to load the activity list",
    "Configure the default notification settings for new users." : "Configure the default notification settings for new users."
},
"nplurals=2; plural=(n != 1);");

==> php81-nextcloud-29.0.8.tgz: share/nextcloud/apps/activity/l10n/en_GB.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Personal activity feed for %s",
    "Your feed URL is invalid" : "Your feed URL is invalid",
    "Activity feed for %1$s" : "Activity feed for %1$s",
    "Activity feed" : "Activity feed",
    "Your settings have been updated." : "Your settings have been updated.",
    "Settings have been updated." : "Settings have been updated.",
    "Recent activity" : "Recent activity",
    "No activities" : "No activities",
    "More activities" : "More activities",
    "Daily activity summary for %s" : "Daily activity summary for %s",
    "_and %n more…_::_and %n more…_" : ["and %n more…","and %n more…"],
    "All activities" : "All activities",
    "By others" : "By others",
    "By you" : "By you",
    "Activity at %s" : "Activity at %s",
    "Hello %s" : "Hello %s",
    "Hello %s," : "Hello %s,",
    "There was some activity at %s" : "There was some activity at %s",
    "_and %n more _::_and %n more _" : ["and %n more","and %n more"],
    "Mail" : "Mail",
    "Push" : "Push",
    "Activity" : "Activity",
    "Notifications" : "Notifications",
    "This application enables people to view a log of activities about them, their files or other data." : "This application enables people to view a log of activities about them, their files or other data.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation.",
    "Activity notification configuration" : "Activity notification configuration",
    "Send email" : "Send email",
    "Send push notification" : "Send push notification",
    "Today" : "Today",
    "Yesterday" : "Yesterday",
    "You need to set up your email address before you can receive notification emails." : "You need to set up your email address before you can receive notification emails.",
    "Send activity emails" : "Send activity emails",
    "As soon as possible" : "As soon as possible",
    "Hourly" : "Hourly",
    "Daily" : "Daily",
    "Weekly" : "Weekly",
    "You commented" : "You commented",
    "Message deleted by author" : "Message deleted by author",
    "Open {filename}" : "Open {filename}",
    "in {path}" : "in {path}",
    "Home" : "Home",
    "Loading activities" : "Loading activities",
    "This stream will show events like additions, changes & shares" : "This stream will show events like additions, changes & shares",
    "No activity yet" : "No activity yet",
    "Loading more activities" : "Loading more activities",
    "No more activities." : "No more activities.",
    "Could not load activities" : "Could not load activities",
    "Activity settings" : "Activity settings",
    "Enable RSS feed" : "Enable RSS feed",
    "RSS feed" : "RSS feed",
    "Copy RSS feed link" : "Copy RSS feed link",
    "Personal notification settings" : "Personal notification settings",
    "Could not enable RSS link" : "Could not enable RSS link",
    "RSS link copied to clipboard" : "RSS link copied to clipboard",
    "Could not copy the RSS link, please copy manually:" : "Could not copy the RSS link, please copy manually:",
    "Unable to load the activity list" : "Unable to load the activity list",
    "Notification" : "Notification",
    "Enable notification emails" : "Enable notification emails",
    "Choose for which activities you want to get an email or push notification." : "Choose for which activities you want to get an email or push notification.",
    "Choose for which activities you want to get a push notification." : "Choose for which activities you want to get a push notification.",
    "Daily activity summary" : "Daily activity summary",
    "Send daily activity summary in the morning" : "Send daily activity summary in the morning",
    "Default settings" : "Default settings",
    "Configure the default notification settings for new accounts." : "Configure the default notification settings for new accounts.",
    "Unable to save the settings" : "Unable to save the settings",
    "No more events to load" : "No more events to load",
    "Could not load activites" : "Could not load activites"
},
"nplurals=2; plural=(n != 1);");
